UnicodeSubstitution

Enum UnicodeSubstitution 

#[non_exhaustive]
pub enum UnicodeSubstitution { Never, Conventional, }
Configuration for using Unicode symbols in the MathML output.

LaTeX commands like \coloneqq can be rendered in MathML either using dedicated Unicode symbols (in this case, \coloneqq would be rendered as ) or using a combination of more basic symbols (in this case, \coloneqq would be rendered as a combination of : and =). The former is preferable in terms of semantics but can look a little different from the LaTeX output, while the latter is more faithful to the LaTeX output but can be less semantically clear.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Never

Never subtitute a set of symbols with their Unicode equivalents.



Conventional

Substitute whenever the LaTeX package unicode-math would substitute, which is a good middle ground between semantics and faithfulness to the LaTeX output.